==> navigation-react-4.9.0.tgz: package/SceneRSCView.js <==
'use client';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { createContext, use, useContext, useEffect, useRef } from 'react';
import useNavigationEvent from './useNavigationEvent.js';
import BundlerContext from './BundlerContext.js';
import ErrorBoundary from './ErrorBoundary.js';
var rscCache = new Map();
var historyCache = {};
var RSCContext = createContext(false);
var SceneViewInner = function (_a) {
    var children = _a.children;
    return (children === null || children === void 0 ? void 0 : children.then) ? use(children) : children;
};
var SceneRSCView = function (_a) {
    var _b, _c;
    var active = _a.active, name = _a.name, dataKeyDeps = _a.dataKeyDeps, errorFallback = _a.errorFallback, children = _a.children;
    var navigationEvent = useNavigationEvent();
    var state = navigationEvent.state, oldState = navigationEvent.oldState, data = navigationEvent.data, _d = navigationEvent.stateNavigator, stateContext = _d.stateContext, historyManager = _d.historyManager;
    var crumbs = stateContext.crumbs, url = stateContext.nextCrumb.crumblessUrl, oldUrl = stateContext.oldUrl, oldData = stateContext.oldData, history = stateContext.history, historyAction = stateContext.historyAction;
    var deserialize = useContext(BundlerContext).deserialize;
    var ancestorFetching = useContext(RSCContext);
    var sceneViewKey = name || (typeof active === 'string' ? active : active[0]);
    var getShow = function (stateKey) { return (active != null && state && (typeof active === 'string' ? stateKey === active : active.indexOf(stateKey) !== -1)); };
    var show = getShow(state.key);
    var ignoreCache = !!navigationEvent['ignoreCache'];
    var cachedHistory = !ignoreCache && history && !!((_b = historyCache[url]) === null || _b === void 0 ? void 0 : _b[sceneViewKey]);
    if (!rscCache.get(navigationEvent))
        rscCache.set(navigationEvent, {});
    var cachedSceneViews = rscCache.get(navigationEvent);
    var renderedSceneView = useRef({ sceneView: undefined, navigationEvent: undefined });
    var fetchedSceneView = cachedSceneViews[sceneViewKey];
    var dataChanged = function () {
        if (!getShow(oldState === null || oldState === void 0 ? void 0 : oldState.key) || !dataKeyDeps || ignoreCache)
            return true;
        if (oldUrl && oldUrl.split('crumb=').length - 1 !== crumbs.length)
            return true;
        for (var i = 0; i < dataKeyDeps.length; i++) {
            if (data[dataKeyDeps[i]] !== oldData[dataKeyDeps[i]])
                return true;
        }
        return false;
    };
    var firstScene = !oldUrl && !ignoreCache;
    var getSceneView = function () {
        if (!show)
            return null;
        if (cachedHistory)
            return historyCache[url][sceneViewKey];
        if (firstScene || ancestorFetching)
            return children;
        if (dataChanged())
            return fetchedSceneView;
        return renderedSceneView.current.sceneView;
    };
    var oldSceneCount = (typeof window !== 'undefined' && ((_c = window.history.state) === null || _c === void 0 ? void 0 : _c.sceneCount)) || 0;
    useEffect(function () {
        var oldNavigationEvent = renderedSceneView.current.navigationEvent;
        renderedSceneView.current = { sceneView: getSceneView(), navigationEvent: navigationEvent };
        if (oldNavigationEvent !== navigationEvent)
            rscCache.delete(oldNavigationEvent);
        if (!cachedSceneViews.__committed) {
            cachedSceneViews.__committed = true;
            rscCache.forEach(function (_a, key) {
                var __committed = _a.__committed;
                if (!__committed)
                    rscCache.delete(key);
            });
        }
        var cacheHistory = function () {
            var _a;
            if (historyAction === 'none' || historyManager.getCurrentUrl() !== stateContext.url)
                return;
            var sceneCount = ((_a = window.history.state) === null || _a === void 0 ? void 0 : _a.sceneCount) || (oldSceneCount + 1);
            if (!historyCache[url])
                historyCache[url] = { count: sceneCount };
            historyCache[url][sceneViewKey] = renderedSceneView.current.sceneView;
            historyCache[url].count = Math.min(historyCache[url].count, sceneCount);
            var historyUrls = Object.keys(historyCache);
            for (var i = 0; i < historyUrls.length && !history; i++) {
                var historyUrl = historyUrls[i];
                var gap = historyCache[historyUrl].count - sceneCount;
                if (historyUrl !== url && (gap === 0 || (historyAction === 'add' && gap > 0)))
                    delete historyCache[historyUrl];
            }
            window.history.replaceState(__assign(__assign({}, window.history.state), { sceneCount: sceneCount }), null);
        };
        cacheHistory();
        window.addEventListener('popstate', cacheHistory);
        return function () { return window.removeEventListener('popstate', cacheHistory); };
    });
    useEffect(function () {
        return function () {
            delete cachedSceneViews[sceneViewKey];
            if (Object.keys(cachedSceneViews).length <= 1)
                rscCache.delete(navigationEvent);
        };
    }, []);
    if (!fetchedSceneView && !cachedHistory && !firstScene && show && !ancestorFetching && dataChanged()) {
        cachedSceneViews[sceneViewKey] = deserialize(historyManager.getHref(url), {
            method: 'post',
            headers: { 'Content-Type': 'application/json' },
            body: { url: url, sceneViewKey: sceneViewKey }
        });
        fetchedSceneView = cachedSceneViews[sceneViewKey];
    }
    return (React.createElement(ErrorBoundary, { errorFallback: errorFallback },
        React.createElement(RSCContext.Provider, { value: ancestorFetching || dataChanged() },
            React.createElement(SceneViewInner, null, getSceneView()))));
};
export default SceneRSCView;

==> navigation-react-4.10.0.tgz: package/SceneRSCView.js <==
'use client';
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { use, useContext, useEffect, useRef, useMemo } from 'react';
import useNavigationEvent from './useNavigationEvent.js';
import BundlerContext from './BundlerContext.js';
import RSCContext from './RSCContext.js';
import ErrorBoundary from './ErrorBoundary.js';
var rscCache = new Map();
var historyCache = {};
var SceneViewInner = function (_a) {
    var children = _a.children;
    return (children === null || children === void 0 ? void 0 : children.then) ? use(children) : children;
};
var SceneRSCView = function (_a) {
    var _b, _c;
    var active = _a.active, name = _a.name, serverRefetch = _a.refetch, errorFallback = _a.errorFallback, children = _a.children;
    var navigationEvent = useNavigationEvent();
    var refetchRef = useRef(serverRefetch);
    var state = navigationEvent.state, oldState = navigationEvent.oldState, data = navigationEvent.data, _d = navigationEvent.stateNavigator, stateContext = _d.stateContext, historyManager = _d.historyManager;
    var crumbs = stateContext.crumbs, url = stateContext.nextCrumb.crumblessUrl, oldUrl = stateContext.oldUrl, oldData = stateContext.oldData, history = stateContext.history, historyAction = stateContext.historyAction;
    var deserialize = useContext(BundlerContext).deserialize;
    var ancestorFetching = useContext(RSCContext).fetching;
    var sceneViewKey = name || (typeof active === 'string' ? active : active[0]);
    var getShow = function (stateKey) { return (active != null && state && (typeof active === 'string' ? stateKey === active : active.indexOf(stateKey) !== -1)); };
    var show = getShow(state.key);
    var ignoreCache = !!navigationEvent['ignoreCache'];
    var cachedHistory = !ignoreCache && history && !!((_b = historyCache[url]) === null || _b === void 0 ? void 0 : _b[sceneViewKey]);
    if (!rscCache.get(navigationEvent))
        rscCache.set(navigationEvent, {});
    var cachedSceneViews = rscCache.get(navigationEvent);
    var renderedSceneView = useRef({ sceneView: undefined, navigationEvent: undefined });
    var fetching = (function () {
        var refetch = refetchRef.current;
        if (!show)
            return false;
        if (!getShow(oldState === null || oldState === void 0 ? void 0 : oldState.key) || !refetch || ignoreCache)
            return true;
        if (oldUrl && oldUrl.split('crumb=').length - 1 !== crumbs.length)
            return true;
        if (typeof refetch === 'function')
            return refetch(stateContext);
        for (var i = 0; i < refetch.length; i++) {
            if (data[refetch[i]] !== oldData[refetch[i]])
                return true;
        }
        return false;
    })();
    var firstScene = !oldUrl && !ignoreCache;
    var oldSceneCount = (typeof window !== 'undefined' && ((_c = window.history.state) === null || _c === void 0 ? void 0 : _c.sceneCount)) || 0;
    useEffect(function () {
        return function () {
            delete cachedSceneViews[sceneViewKey];
            if (Object.keys(cachedSceneViews).length <= 1)
                rscCache.delete(navigationEvent);
        };
    }, []);
    if (!cachedSceneViews[sceneViewKey] && !cachedHistory && !firstScene && !ancestorFetching && fetching) {
        cachedSceneViews[sceneViewKey] = deserialize(historyManager.getHref(url), {
            method: 'post',
            headers: { 'Content-Type': 'application/json' },
            body: { url: url, sceneViewKey: sceneViewKey }
        });
    }
    var sceneView = (function () {
        if (!show)
            return null;
        if (cachedHistory)
            return historyCache[url][sceneViewKey];
        if (firstScene || ancestorFetching)
            return children;
        if (fetching)
            return cachedSceneViews[sceneViewKey];
        return renderedSceneView.current.sceneView;
    })();
    useEffect(function () {
        var oldNavigationEvent = renderedSceneView.current.navigationEvent;
        renderedSceneView.current = { sceneView: sceneView, navigationEvent: navigationEvent };
        if (oldNavigationEvent !== navigationEvent)
            rscCache.delete(oldNavigationEvent);
        if (!cachedSceneViews.__committed) {
            cachedSceneViews.__committed = true;
            rscCache.forEach(function (_a, key) {
                var __committed = _a.__committed;
                if (!__committed)
                    rscCache.delete(key);
            });
        }
        var cacheHistory = function () {
            var _a;
            if (historyAction === 'none' || historyManager.getCurrentUrl() !== stateContext.url)
                return;
            var sceneCount = ((_a = window.history.state) === null || _a === void 0 ? void 0 : _a.sceneCount) || (oldSceneCount + 1);
            if (!historyCache[url])
                historyCache[url] = { count: sceneCount };
            historyCache[url][sceneViewKey] = renderedSceneView.current.sceneView;
            historyCache[url].count = Math.min(historyCache[url].count, sceneCount);
            var historyUrls = Object.keys(historyCache);
            for (var i = 0; i < historyUrls.length && !history; i++) {
                var historyUrl = historyUrls[i];
                var gap = historyCache[historyUrl].count - sceneCount;
                if (historyUrl !== url && (gap === 0 || (historyAction === 'add' && gap > 0)))
                    delete historyCache[historyUrl];
            }
            window.history.replaceState(__assign(__assign({}, window.history.state), { sceneCount: sceneCount }), null);
        };
        cacheHistory();
        window.addEventListener('popstate', cacheHistory);
        return function () { return window.removeEventListener('popstate', cacheHistory); };
    });
    var rscContextVal = useMemo(function () { return ({
        fetching: ancestorFetching || fetching,
        setRefetch: function (refetch) { return refetchRef.current = refetch !== undefined ? refetch : serverRefetch; }
    }); }, [ancestorFetching || fetching]);
    return (React.createElement(ErrorBoundary, { errorFallback: errorFallback },
        React.createElement(RSCContext.Provider, { value: rscContextVal },
            React.createElement(SceneViewInner, null, sceneView))));
};
export default SceneRSCView;
